==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/CGI/Configuration.pm <==
#
# WiKicker
#
#  Configuration.pm
#
#
# Copyright (C) 2003,2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: Configuration.pm,v 1.24 2004/04/30 08:28:52 naney Exp $
#
#
package WiKicker::CGI::Configuration;

use 5.005;
use strict;
use Carp;
use WiKicker::Configuration;
use WiKicker::Properties::Default;
use AutoLoader 'AUTOLOAD';

use vars qw(@ISA %properties_pool);

BEGIN {
  @ISA = qw(WiKicker::Configuration);
}

sub new {
  my ($class, %options) = @_;

  my $self = bless {}, $class;

  my $properties_file = '';
  if (exists $options{properties_file}) {
    $properties_file = $options{properties_file};
  }

  $self->_load_configuration($properties_file);

  #-IFDEBUG: use WiKicker;
  #-IFDEBUG: WiKicker::total_size("%properties_pool", \%properties_pool);

  return $self;
};

sub _load_configuration {
  my ($self, $properties_file) = @_;

  if ($properties_file eq '') {
    $properties_file = $self->_get_properties_file();
  }
  if ($properties_file) {
    my @stat = stat($properties_file);
    if (exists $properties_pool{$properties_file}) {
      if ($stat[9] == $properties_pool{$properties_file}->{mtime}) {
        $self->properties($properties_pool{$properties_file}->{properties});
      }
    }
    my $default_properties = WiKicker::Properties::Default->new;
    my $properties = WiKicker::ReadOnlyProperties
      ->new(parent => $default_properties,
            file_name => $properties_file);
    $properties_pool{$properties_file}->{mtime} = $stat[9];
    $properties_pool{$properties_file}->{properties} = $properties;
    $properties->set_last_modified($stat[9]);

    $self->properties($properties);
  }
  else {
    my $default_properties = WiKicker::Properties::Default->new;
    $self->properties($default_properties);
  }
}

sub _get_properties_file {
  my $self = shift;

  my $script = $ENV{SCRIPT_FILENAME};
  return '' unless $script;
  my $file = $script .= '.properties';
  if (-f $file) {
    return $file;
  }
  else {
    return '';
  }
}


sub view_class {
  my ($self, $forward, $format) = @_;

  my $class = $self->properties->get("view.$forward.$format") || '';
  $class =~ s/^\s+//;
  $class =~ s/\s+$//;
  if ($class) {
    return $class;
  }
  $class = $self->properties->get("view.$forward") || '';
  $class =~ s/^\s+//;
  $class =~ s/\s+$//;
  if ($class) {
    return $class;
  }
  warn "No view for view.$forward(.$format)";
  return "WiKicker::WikiCGI::View::HTML::NoViewError";
}

sub pseudo_class {
  my ($self, $name) = @_;

  return $self->properties->get("pseudo." . $name) || '';
}

sub is_pseudo_page {
  my ($self, $name) = @_;

  return $self->pseudo_class($name);
}

sub export_page {
  my ($self, $name) = @_;

  return $self->properties->get("export.$name.file") || '';
}

sub cookie_domain {
  my $self = shift;

  my $domain = $self->properties->get('cookie.domain');
  if ($domain) {
    return $domain;
  }
  else {
    return $ENV{HTTP_HOST};
  }
}

sub cookie_path {
  my $self = shift;

  my $path = $self->properties->get('cookie.path');
  if ($path) {
    return $path;
  }
  else {
    $path = $ENV{SCRIPT_NAME};
    $path =~ s|[^/]+$||;
    return $path;
  }
}

sub wikicker_home {
  my $self = shift;

  if (exists $self->{wikicker_home}) {
    return $self->{wikicker_home};
  }

  my $value = $self->properties->get('wikicker.home');
  if (defined $value) {
    $self->{wikicker_home} = $value;
    return $value;
  }
  if ($ENV{SCRIPT_FILENAME}) {
    my @path = split('/', $ENV{SCRIPT_FILENAME});
    pop(@path);
    $self->{wikicker_home} = join('/', @path);
  }
  else {
    $self->{wikicker_home} = '';
  }

  return $self->{wikicker_home};
}

sub html_external_script_list {
  my $self = shift;

  my $symbol_str = $self->properties->get("html.externalscript") || '';
  if ($symbol_str eq '') {
    return [];
  }
  my @symbol = split(/\s+/, $symbol_str);
  my @result = ();
  for my $s (@symbol) {
    my $uri = $self->properties->get("html.externalscript.$s.uri") || '';
    next if $uri eq '';
    my $type = $self->properties->get("html.externalscript.$s.type") || '';
    next if $type eq '';
    my $charset = $self->properties->get("html.externalscript.$s.charset") || '';
    push(@result, {uri => $uri, type => $type, charset => $charset});
  }
  return \@result;
}

sub automaticlink_extraset_list {
  my $self = shift;

  my $symbol_str = $self->properties->get("automaticlink.extraset") || '';
  if ($symbol_str eq '') {
    return [];
  }
  my @symbol = split(/\s+/, $symbol_str);
  my @result = ();
  for my $s (@symbol) {
    my $scheme = $self->properties->get("automaticlink.extraset.$s.scheme") || '';
    next if $scheme eq '';
    my $file = $self->properties->get("automaticlink.extraset.$s.file") || '';
    next if $file eq '';
    next unless (-e $file);
    my @words = ();
    unless (open (FILE, $file)) {
      warn "Can't open '$file': $!";
      next;
    }
    while (<FILE>) {
      chomp;
      s/^\s+//;
      s/\s+$//;
      push(@words, $_);
    }
    close(FILE);
    push(@result, { words => \@words, scheme => $scheme});
  }
  return \@result;
}


sub is_busy_to_search;
sub admin_name;

1;

__END__

sub is_busy_to_search {
  my ($self, $load_average) = @_;

  croak "no load average object" unless defined $load_average;

  my $limit = $self->properties->get('param.search.loadlimit') || '';

  unless ($limit) {
    return 0;
  }

  my $load_average_1 = $load_average->load_average_1;

  if ($load_average_1 < 0) {
    return 0;
  }
  if ($load_average_1 > $limit) {
    return 1;
  }

  return 0;
}

sub admin_name {
  my $self = shift;

  my $value = $self->properties->get('admin.home');
  if (defined $value) {
    return $value;
  }
  if ($ENV{SERVER_ADMIN}) {
    return $ENV{SERVER_ADMIN};
  }
  return 'unknown';
}

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/CGI/Configuration.pm <==
#
# WiKicker
#
#  Configuration.pm
#
#
# Copyright (C) 2003,2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: Configuration.pm,v 1.25 2004/08/03 12:55:52 naney Exp $
#
#
package WiKicker::CGI::Configuration;

use 5.005;
use strict;
use Carp;
use WiKicker::Configuration;
use WiKicker::Properties::Default;
use AutoLoader 'AUTOLOAD';

use vars qw(@ISA %properties_pool);

BEGIN {
  @ISA = qw(WiKicker::Configuration);
}

sub new {
  my ($class, %options) = @_;

  my $self = bless {}, $class;

  my $properties_file = '';
  if (exists $options{properties_file}) {
    $properties_file = $options{properties_file};
  }

  $self->_load_configuration($properties_file);

  #-IFDEBUG: use WiKicker;
  #-IFDEBUG: WiKicker::total_size("%properties_pool", \%properties_pool);

  return $self;
};

sub _load_configuration {
  my ($self, $properties_file) = @_;

  if ($properties_file eq '') {
    $properties_file = $self->_get_properties_file();
  }
  if ($properties_file) {
    my @stat = stat($properties_file);
    if (exists $properties_pool{$properties_file}) {
      if ($stat[9] == $properties_pool{$properties_file}->{mtime}) {
        $self->properties($properties_pool{$properties_file}->{properties});
      }
    }
    my $default_properties = WiKicker::Properties::Default->new;
    my $properties = WiKicker::ReadOnlyProperties
      ->new(parent => $default_properties,
            file_name => $properties_file);
    $properties_pool{$properties_file}->{mtime} = $stat[9];
    $properties_pool{$properties_file}->{properties} = $properties;
    $properties->set_last_modified($stat[9]);

    $self->properties($properties);
  }
  else {
    Log::Log4perl->get_logger->warn('No properties file');
    my $default_properties = WiKicker::Properties::Default->new;
    $self->properties($default_properties);
  }
}

sub _get_properties_file {
  my $self = shift;

  my $script = $ENV{SCRIPT_FILENAME};
  return '' unless $script;
  my $file = $script .= '.properties';
  if (-f $file) {
    return $file;
  }
  else {
    return '';
  }
}


sub view_class {
  my ($self, $forward, $format) = @_;

  my $class = $self->properties->get("view.$forward.$format") || '';
  $class =~ s/^\s+//;
  $class =~ s/\s+$//;
  if ($class) {
    return $class;
  }
  $class = $self->properties->get("view.$forward") || '';
  $class =~ s/^\s+//;
  $class =~ s/\s+$//;
  if ($class) {
    return $class;
  }
  warn "No view for view.$forward(.$format)";
  return 'WiKicker::WikiCGI::View::HTML::NoViewError';
}

sub pseudo_class {
  my ($self, $name) = @_;

  return $self->properties->get('pseudo.' . $name) || '';
}

sub is_pseudo_page {
  my ($self, $name) = @_;

  return $self->pseudo_class($name);
}

sub export_page {
  my ($self, $name) = @_;

  return $self->properties->get("export.$name.file") || '';
}

sub cookie_domain {
  my $self = shift;

  my $domain = $self->properties->get('cookie.domain');
  if ($domain) {
    return $domain;
  }
  else {
    return $ENV{HTTP_HOST};
  }
}

sub cookie_path {
  my $self = shift;

  my $path = $self->properties->get('cookie.path');
  if ($path) {
    return $path;
  }
  else {
    if (exists $ENV{SCRIPT_NAME}) {
      $path = $ENV{SCRIPT_NAME};
      $path =~ s|[^/]+$||;
      return $path;
    }
    else {
      return '/';
    }
  }
}

sub wikicker_home {
  my $self = shift;

  if (exists $self->{wikicker_home}) {
    return $self->{wikicker_home};
  }

  my $value = $self->properties->get('wikicker.home');
  if (defined $value) {
    $self->{wikicker_home} = $value;
    return $value;
  }
  if ($ENV{SCRIPT_FILENAME}) {
    my @path = split('/', $ENV{SCRIPT_FILENAME});
    pop(@path);
    $self->{wikicker_home} = join('/', @path);
  }
  else {
    Log::Log4perl->get_logger->warn('No WiKicker home');
    $self->{wikicker_home} = '';
  }

  return $self->{wikicker_home};
}

sub html_external_script_list {
  my $self = shift;

  my $symbol_str = $self->properties->get('html.externalscript') || '';
  if ($symbol_str eq '') {
    return [];
  }
  my @symbol = split(/\s+/, $symbol_str);
  my @result = ();
  for my $s (@symbol) {
    my $uri = $self->properties->get("html.externalscript.$s.uri") || '';
    next if $uri eq '';
    my $type = $self->properties->get("html.externalscript.$s.type") || '';
    next if $type eq '';
    my $charset = $self->properties->get("html.externalscript.$s.charset") || '';
    push(@result, {uri => $uri, type => $type, charset => $charset});
  }
  return \@result;
}

sub automaticlink_extraset_list {
  my $self = shift;

  my $symbol_str = $self->properties->get("automaticlink.extraset") || '';
  if ($symbol_str eq '') {
    return [];
  }
  my @symbol = split(/\s+/, $symbol_str);
  my @result = ();
  for my $s (@symbol) {
    my $scheme = $self->properties->get("automaticlink.extraset.$s.scheme") || '';
    next if $scheme eq '';
    my $file = $self->properties->get("automaticlink.extraset.$s.file") || '';
    next if $file eq '';
    next unless (-e $file);
    my @words = ();
    unless (open (FILE, $file)) {
      warn "Can't open '$file': $!";
      next;
    }
    while (<FILE>) {
      chomp;
      s/^\s+//;
      s/\s+$//;
      push(@words, $_);
    }
    close(FILE);
    push(@result, { words => \@words, scheme => $scheme});
  }
  return \@result;
}


sub is_busy_to_search;
sub admin_name;

1;

__END__

sub is_busy_to_search {
  my ($self, $load_average) = @_;

  croak 'no load average object' unless defined $load_average;

  my $limit = $self->properties->get('param.search.loadlimit') || '';

  unless ($limit) {
    return 0;
  }

  my $load_average_1 = $load_average->load_average_1;

  if ($load_average_1 < 0) {
    return 0;
  }
  if ($load_average_1 > $limit) {
    return 1;
  }

  return 0;
}

sub admin_name {
  my $self = shift;

  my $value = $self->properties->get('admin.home');
  if (defined $value) {
    return $value;
  }
  if ($ENV{SERVER_ADMIN}) {
    return $ENV{SERVER_ADMIN};
  }
  return 'unknown';
}
